@@ -2,7 +2,6 @@ import os
 import shlex
 import subprocess
 import sys
-from typing import List, Tuple
 
 from semantic_version import Version
 
@@ -10,7 +9,7 @@ from .errors import raise_error
 
 
 # return (output, isOk)
-def call(cmd: str, printOutput: bool = False) -> Tuple[str, bool]:
+def call(cmd: str, printOutput: bool = False) -> tuple[str, bool]:
     # print(f"{printOutput = }, {cmd = }")
     if sys.platform == "win32":
         args = cmd
@@ -38,6 +37,8 @@ def getAdb() -> str:
     androidHome = os.getenv("ANDROID_HOME")
     if androidHome is None:
         androidHome = os.getenv("ANDROID_SDK")
+    if androidHome is None:
+        androidHome = os.getenv("ANDROID_SDK_ROOT")
     if androidHome is None:
         # print('can not found ANDROID_HOME/ANDROID_SDK in environment value')
         return "adb"
@@ -49,6 +50,8 @@ def getAapt() -> str:
     androidHome = os.getenv("ANDROID_HOME")
     if androidHome is None:
         androidHome = os.getenv("ANDROID_SDK")
+    if androidHome is None:
+        androidHome = os.getenv("ANDROID_SDK_ROOT")
     if androidHome is None:
         print("can not found ANDROID_HOME/ANDROID_SDK in environment value")
         return "aapt"
